@@ -3,6 +3,10 @@ var HostedGit = require('../index')
 var test = require('tap').test
 
 test('basic', function (t) {
+  const h = HostedGit.fromUrl('github:user/project')
+  t.equal(h._fill(), undefined)
+  t.is(h.constructor, HostedGit)
+  t.is(h.constructor.name, 'GitHost')
   t.is(HostedGit.fromUrl('https://google.com'), undefined, 'null on failure')
   t.is(HostedGit.fromUrl('https://github.com/abc/def').getDefaultRepresentation(), 'https', 'match https urls')
   t.is(HostedGit.fromUrl('https://github.com/abc/def/').getDefaultRepresentation(), 'https', 'match URLs with a trailing slash')
@@ -32,5 +36,7 @@ test('basic', function (t) {
   t.is(HostedGit.fromUrl('git+file:///foo/bar'), undefined, 'url that has no host')
   t.is(HostedGit.fromUrl('github.com/abc/def/'), undefined, 'forgot the protocol')
   t.is(HostedGit.fromUrl('completely-invalid'), undefined, 'not a url is not hosted')
+
+  t.is(HostedGit.fromUrl('http://github.com/foo/bar').toString(), 'git+ssh://git@github.com/foo/bar.git', 'github http protocol use git+ssh urls')
   t.end()
 })
